@@ -1,6 +1,8 @@
 import argparse
 import os
 import sys
+from datetime import datetime
+
 
 try:
     sys.stdin.reconfigure(encoding="utf-8")
@@ -79,7 +81,13 @@ def main():
         return
 
     if not args.keep:
-        check.delete_not_exist()
+        info=check.delete_not_exist()
+        if len(info) > 1:
+            info_str='\n -'.join(info)
+            print(f'[{datetime.now().strftime("%H:%M:%S")}] 🗑️ Delete from blog:\n{info_str}')
+        elif len(info) == 1:
+            info_str = info[0]
+            print(f'🗑️ Delete "{info_str}" from blog')
         stop_share = 1
     else:
         stop_share = 0
