@@ -5,6 +5,7 @@ from pathlib import Path
 import frontmatter
 from unidecode import unidecode
 
+from YAFPA.common import convert_all as exclude
 from YAFPA.common import global_value as settings
 from YAFPA.common import metadata as mt
 
@@ -46,18 +47,23 @@ def delete_file(filepath, folder):
             return True
     return False
 
-
 def delete_not_exist():
     vault_file = []
+    excluded=[]
+    info=[]
     important_folder = ["_includes", "_layout", "_site", "assets", "script"]
     for i, j, k in os.walk(vault):
         for ki in k:
             vault_file.append(os.path.basename(ki))
+            if exclude.exclude_folder(i + os.sep + ki):
+                excluded.append(os.path.basename(ki))
     for file in glob.iglob(f"{BASEDIR}/_*/**"):
         if not (any(i in file for i in important_folder)):
-            if os.path.basename(file) not in vault_file:
+            #Delete the file from the database if moved in the excluded folder
+            if os.path.basename(file) not in vault_file or os.path.basename(file) in excluded: #or if file in file_excluded
                 os.remove(file)
-
+                info.append(os.path.basename(file))
+    return info
 
 def check_file(filepath, folder):
     post_file = []
